fisx: fisx::SimpleSpecfile Class Reference

fisx

Public Member Functions | List of all members
fisx::SimpleSpecfile Class Reference

## Public Member Functions
| SimpleSpecfile (std::string fileName)
void | setFileName (std::string fileName)
int | getNumberOfScans ()
std::vector< std::string > | getScanHeader (int scanIndex)
std::vector< std::string > | getScanLabels (int scanIndex)
std::vector< std::vector< double > > | getScanData (int scanIndex)

The documentation for this class was generated from the following files:

- fisx_simplespecfile.h
- fisx_simplespecfile.cpp